<template>
  <div class="box">
    <div style="display: flex">
      <el-form ref="searchForm" :model="searchForm" label-width="80px" class="searchTop">
        <CascaderCompany
          :companyIds.sync="searchForm.companyId"
          :roadSegmentId.sync="searchForm.croadSegmentId"
          :placeholder="'请选择公司名称'"
        />

        <el-select v-model="searchForm.croadSegmentId" placeholder="请选择路段" clearable>
          <el-option v-for="item in roadData" :key="item.id" :label="item.name" :value="item.id"> </el-option>
        </el-select>

        <el-date-picker
          v-model="searchForm.cissueDate"
          type="daterange"
          range-separator="至"
          format="yyyy-MM-dd"
          value-format="yyyy-MM-dd"
          start-placeholder="开始日期"
          end-placeholder="结束日期"
          style="margin-right: 10px"
        >
        </el-date-picker>

        <el-button size="small" @click="findinfo" type="primary"> 查询 </el-button>
        <el-button size="small" @click="downLoad" type="primary" plain> 导出 </el-button>
      </el-form>
    </div>

    <ht-table
      @load="loadData"
      :data="data"
      :pageResult="pageResult"
      :selection="true"
      :show-custom-column="false"
      :show-export="false"
      ref="htTable"
    >
      <template>
        <ht-table-column prop="roadName" label="路段名称" :show-overflow-tooltip="true" />
        <ht-table-column prop="itemName" label="科目名称" :show-overflow-tooltip="true" />
        <ht-table-column prop="finishCount" label="已完成" :show-overflow-tooltip="true" />
        <ht-table-column prop="constructionCount" label="施工中" :show-overflow-tooltip="true" />
        <ht-table-column prop="overdueCount" label="已逾期" :show-overflow-tooltip="true" />
        <ht-table-column prop="contractMoney" label="合同金额" :show-overflow-tooltip="true" />
        <ht-table-column prop="finishMoney" label="完成金额" :show-overflow-tooltip="true" />
        <ht-table-column prop="implementationRate" label="执行率" :show-overflow-tooltip="true" />
      </template>
    </ht-table>
  </div>
</template>

<script>
import basicData from '@/api/basicData.js'
import CascaderCompany from '@/components/selector/CascaderCompany.vue'
export default {
  name: 'MaintenanceCostAccount',
  components: {
    CascaderCompany,
  },
  data() {
    return {
      searchForm: {},
      pageResult: {
        page: 1,
        pageSize: 20,
        total: 0,
      },
      params: {},
      data: [],
      roadData: [],
    }
  },
  created() {
    this.getroad()
  },
  methods: {
    loadData(param, cb) {
      this.params = param
      this.cb = cb
      this.$http
        .post('${yhxt}' + '/workOrderInformation/v1/orderItemCountReport', param)
        .then((res) => {
          this.data = res.data.rows
          this.pageResult = {
            page: res.data.page,
            pageSize: res.data.pageSize,
            total: res.data.total,
          }
        })
        .finally(() => {
          if (cb) {
            cb()
          }
        })
    },
    getroad() {
      let arr = []
      basicData.getRoadManagement().then((res) => {
        res.rows.forEach((item) => {
          arr.push({
            name: item.name,
            id: item.id,
          })
        })
      })
      this.roadData = arr
    },
    findinfo() {
      let query = this.searchForm
      let querys = []
      for (let i in query) {
        if (query[i]) {
          if ( i == 'cissueDate' && query['cissueDate'] && query['cissueDate'].length !== 0) {
            querys.push({
              group: 'main',
              operation: 'GREAT_EQUAL',
              property: 'cissueDate',
              relation: 'AND',
              value: query[i][0],
            })
            querys.push({
              group: 'main',
              operation: 'LESS_EQUAL',
              property: 'cissueDate',
              relation: 'AND',
              value: query[i][1],
            })
          } else {
            querys.push({
              group: 'main',
              operation: 'EQUAL',
              property: i,
              relation: 'AND',
              value: query[i],
            })
          }
        }
      }
      this.params.querys = querys
      this.loadData(this.params, this.cb)
    },
    downLoad() {
      this.$confirm('确认导出当前页数据吗?', '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      }).then(() => {
        this.$http
          .downloadPost('${yhxt}/workOrderInformation/v1/orderItemCountReportExport', {
            pageBean: {
              page: -1,
            },
          })
          .then((res) => {
            this.$message.success('导出成功')
          })
      })
    },
  },
}
</script>

<style lang="scss" scoped>
.box {
  padding: 10px;
}
.searchTop > div {
  max-width: 200px;
  background-color: #103c5d;
  border-color: #103c5d;
}
/deep/ .el-range-separator {
  color: #fff;
}
/deep/ input::placeholder {
  color: #fff;
}
/deep/ .el-date-editor input::placeholder {
  color: #fff;
}
</style>
